Check if point 1 is visible from point 2 given a certain elevation model
cansee(r, xy1, xy2, h1 = 0, h2 = 0, reso)A DEM raster
A vector/matrix with X and Y coordinates for Point 1
A vector/matrix with X and Y coordinates for Point 2
A numeric giving the extra height offset for Point 1
A numeric giving the extra height offset for Point 2
The minimal resolution of the DEM raster. It is
calculated in viewshed and passed along.
A boolean value, indicating if the point (xy2) is visible
Other Viewshed Analysis: interpol_view,
plot_viewshed, rasterprofile,
viewTo, viewshed