| hexa_area | R Documentation |
The function takes a Simple Feature Polygon and a size argument and creates a list with an indexed matrix with coordinates and a Simple Feature object, that consists of hexagonal grids.
hexa_area(area, size = 500, plot_grid = FALSE)
area |
Simple Feature polygon of the site |
size |
Cell size of the grid in metres |
plot_grid |
Draw the grid |
Returns a list with 2 elements. List element 1 will have the grid cell IDS, and the X and Y coordinates of the centers of each grid cell. List element 2 is the grid as Simple Feature Polygons, which is used for plotting purposes.
Other Helper Functions:
get_grids(),
grid_area(),
isSpatial(),
permutations(),
read_power_curve(),
splitAt(),
wind_from_series(),
wind_from_uv(),
windata_format()
library(sf)
## Exemplary input Polygon with 2km x 2km:
Poly <- sf::st_as_sf(sf::st_sfc(
sf::st_polygon(list(cbind(
c(4498482, 4498482, 4499991, 4499991, 4498482),
c(2668272, 2669343, 2669343, 2668272, 2668272)
))),
crs = 3035
))
HexGrid <- hexa_area(Poly, 100, TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.