Learn R Programming

windfarmGA (version 5.0.0)

permutations: Enumerate the Combinations or Permutations of the Elements of a Vector

Description

permutations enumerates the possible permutations. The function is forked and minified from gtools::permutations

Usage

permutations(n, r, v = 1:n)

Value

Returns a matrix where each row contains a vector of length r.

Arguments

n

Size of the source vector

r

Size of the target vectors

v

Source vector. Defaults to 1:n

Author

Original versions by Bill Venables. Extended to handle repeats.allowed by Gregory R. Warnes

References

Venables, Bill. "Programmers Note", R-News, Vol 1/1, Jan. 2001. https://cran.r-project.org/doc/Rnews/

See Also

Other Helper Functions: get_grids(), grid_area(), hexa_area(), isSpatial(), read_power_curve(), splitAt(), wind_from_series(), wind_from_uv(), windata_format()