| plot_leaflet | R Documentation |
Plot a resulting wind farm on a leaflet map. Wakes are
downwind cones (Jensen search angle), not circles. Terrain rasters
from result$terrainModel are optional overlay layers.
plot_leaflet(
result,
area,
which = 1,
orderitems = TRUE,
grid = NULL,
wind = NULL,
terrain = NULL
)
result |
The output of |
area |
Site polygon ( |
which |
A numeric value, indicating which individual to plot. The
default is 1. Combined with |
orderitems |
A logical value indicating whether the results should be
ordered by energy values |
grid |
Optional grid polygons. By default they are rebuilt from
|
wind |
Optional wind table ( |
terrain |
Optional output of |
Returns a leaflet map.
## Not run:
## Plot the best wind farm on a leaflet map (ordered by energy values)
plot_leaflet(result = resulthex, area = sp_polygon, which = 1)
## Plot the last wind farm (ordered by chronology).
plot_leaflet(
result = resulthex, area = sp_polygon, orderitems = FALSE,
which = 1
)
## Plot the best wind farm on a leaflet map with the rectangular Grid
Grid <- grid_area(sp_polygon, size = 150, prop = 0.4)
plot_leaflet(
result = resultrect, area = sp_polygon, which = 1,
grid = Grid[[2]]
)
## Plot the last wind farm with hexagonal Grid
Grid <- hexa_area(sp_polygon, size = 75)
plot_leaflet(
result = resulthex, area = sp_polygon, which = 1,
grid = Grid[[2]]
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.