| plot_result | R Documentation |
Draw the best layout(s) on the site. Turbine labels are the total wake in percent. Default is the single best energy layout.
plot_result(
result,
area,
best = 1,
plot_en = 1,
terrain = FALSE,
plot_grid = TRUE,
ccl_roughness = NULL,
ccl = NULL,
weibull_src = NULL
)
result |
The output of |
area |
Site polygon ( |
best |
How many distinct best layouts to draw. Default is 1. |
plot_en |
A numeric value that indicates if the best energy or efficiency
output should be plotted. |
terrain |
Draw terrain rasters for the best layout. Reuses
|
plot_grid |
If |
ccl_roughness |
Path to the CLC legend CSV ( |
ccl |
Path to a Corine Land Cover raster when |
weibull_src |
|
Returns a data.frame of the best (energy/efficiency) individual during all iterations
Other Plotting Functions:
generation_layouts(),
plot_cell_heatmap(),
plot_cloud(),
plot_development(),
plot_evolution(),
plot_generation(),
plot_parkfitness(),
plot_population(),
plot_windfarmGA(),
plot_windrose(),
population_census(),
random_search_single()
## Not run:
## Add some data examples from the package
library(sf)
area <- sf::st_as_sf(sf::st_sfc(
sf::st_polygon(list(cbind(
c(4498482, 4498482, 4499991, 4499991, 4498482),
c(2668272, 2669343, 2669343, 2668272, 2668272)
))),
crs = 3035
))
## Plot the results of a hexagonal grid optimization
plot_result(resulthex, area, best = 1, plot_en = 1, terrain = FALSE)
## Plot the results of a rectangular grid optimization
plot_result(resultrect, area, best = 1, plot_en = 1, terrain = FALSE)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.