population_census: Population size and diversity per generation

View source: R/plots.R

population_censusR Documentation

Population size and diversity per generation

Description

Counts evaluated individuals, distinct layouts, duplicates dropped before the next generation, selected parents, elites, elite offspring and grid cells (this generation and cumulative).

Usage

population_census(result)

Arguments

result

The output of genetic_algorithm

Value

A data.frame with one row per generation.

See Also

Other Plotting Functions: generation_layouts(), plot_cell_heatmap(), plot_cloud(), plot_development(), plot_evolution(), plot_generation(), plot_parkfitness(), plot_population(), plot_result(), plot_windfarmGA(), plot_windrose(), random_search_single()

Examples


population_census(resultrect)


windfarmGA documentation built on Sept. 14, 2026, 9:08 a.m.