| population_census | R Documentation |
Counts evaluated individuals, distinct layouts, duplicates dropped before the next generation, selected parents, elites, elite offspring and grid cells (this generation and cumulative).
population_census(result)
result |
The output of |
A data.frame with one row per generation.
Other Plotting Functions:
generation_layouts(),
plot_cell_heatmap(),
plot_cloud(),
plot_development(),
plot_evolution(),
plot_generation(),
plot_parkfitness(),
plot_population(),
plot_result(),
plot_windfarmGA(),
plot_windrose(),
random_search_single()
population_census(resultrect)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.