Learn R Programming

windfarmGA (version 5.0.0)

population_census: Population size and diversity per generation

Description

Counts evaluated individuals, distinct layouts, duplicates dropped before the next generation, selected parents, elites, elite offspring and grid cells (this generation and cumulative).

Usage

population_census(result)

Value

A data.frame with one row per generation.

Arguments

result

The output of genetic_algorithm

See Also

Other Plotting Functions: generation_layouts(), plot_cell_heatmap(), plot_cloud(), plot_development(), plot_evolution(), plot_generation(), plot_parkfitness(), plot_population(), plot_result(), plot_windfarmGA(), plot_windrose(), random_search_single()

Examples

Run this code
# \donttest{
population_census(resultrect)
# }

Run the code above in your browser using DataLab