View source: R/random_search.R
| random_search_single | R Documentation |
Perform a random search for a single turbine, to further optimize the output of the wind farm layout.
random_search_single(
result,
area,
runs = 20,
plot = FALSE,
max_dist = 2.2,
terrain = NULL,
weibull = NULL,
weibull_src = NULL,
ccl = NULL,
ccl_roughness = NULL,
turbine = NULL
)
result |
The resulting matrix of the function |
area |
Site polygon ( |
runs |
How many jittered layouts to try per |
plot |
Draw the random-search layouts |
max_dist |
A numeric value multiplied by the rotor radius to perform collision checks. Default is 2.2 |
terrain |
|
weibull |
|
weibull_src |
|
ccl |
Path to a Corine Land Cover raster when |
ccl_roughness |
Path to the CLC legend CSV ( |
turbine |
Grid cell ID of the turbine to move. If |
Returns a list
Other Randomization:
plot_random_search(),
random_search()
Other Plotting Functions:
generation_layouts(),
plot_cell_heatmap(),
plot_cloud(),
plot_development(),
plot_evolution(),
plot_generation(),
plot_parkfitness(),
plot_population(),
plot_result(),
plot_windfarmGA(),
plot_windrose(),
population_census()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.