powered by
The function is used by the crossover method to split a genetic code at certain intervals. See also crossover.
crossover
splitAt(x, pos)
Returns a list of the split genetic code.
A numeric variable that represents an individual's binary genetic code
A numeric value that indicates where to split the genetic code
Other Helper Functions: get_grids(), grid_area(), hexa_area(), isSpatial(), permutations(), read_power_curve(), wind_from_series(), wind_from_uv(), windata_format()
get_grids()
grid_area()
hexa_area()
isSpatial()
permutations()
read_power_curve()
wind_from_series()
wind_from_uv()
windata_format()
splitAt(1:100, 20) splitAt(as.matrix(1:100), 20)
Run the code above in your browser using DataLab