Learn R Programming

windfarmGA (version 5.0.0)

turbine_influences: Find potentially influencing turbines

Description

Find all turbines that could potentially influence another turbine and save them to a list.

Usage

turbine_influences(t, wnkl, dist, area, dirct, plot_angles = FALSE)

Value

Returns a list of all individuals of the current generation which could potentially influence other turbines. List includes the relevant coordinates, the distances and angles in between and assigns the Point ID.

Arguments

t

A data.frame of the current individual with X and Y coordinates

wnkl

Wake opening angle in degrees. Turbines outside this cone are ignored.

dist

A numeric value indicating the distance, after which the wake effects are considered to be eliminated.

area

Site polygon

dirct

Current wind direction

plot_angles

Plot distances and angles

See Also

Other Wind Energy Calculation Functions: barometric_height(), calculate_energy(), circle_intersection(), get_dist_angles()

Examples

Run this code
## Exemplary input Polygon with 2km x 2km:
library(sf)

area <- sf::st_as_sf(sf::st_sfc(
  sf::st_polygon(list(cbind(
    c(0, 0, 2000, 2000, 0),
    c(0, 2000, 2000, 0, 0)
  ))),
  crs = 3035
))

t <- st_coordinates(st_sample(area, 10))
t <- cbind(t, "Z" = 1)
wnkl <- 20
dist <- 100000
dirct <- 0

res <- turbine_influences(t, wnkl, dist, area, dirct, plot_angles = TRUE)

Run the code above in your browser using DataLab